@@ -1,4 +1,5 @@
 import logging
+import threading
 import time
 
 from kikyo import Kikyo, DataHub
@@ -15,6 +16,7 @@ class KikyoConsumer(BaseConsumer):
         self.is_running = True
         self.consumer = None
         self._delay = self.worker.settings.get('consumer_delay')
+        self._lock = threading.Lock()
 
     @property
     def kikyo(self) -> Kikyo:
@@ -25,19 +27,21 @@ class KikyoConsumer(BaseConsumer):
         return self.worker.name
 
     def run(self, name):
-        if self.consumer is None:
-            datahub = self.kikyo.component(cls=DataHub)
-            self.consumer = datahub.subscribe(
-                name,
-                subscription_name=f'kikyopp.{self.worker_name}',
-                auto_ack=False,
-            )
+        with self._lock:
+            if self.consumer is None:
+                datahub = self.kikyo.component(cls=DataHub)
+                self.consumer = datahub.subscribe(
+                    name,
+                    subscription_name=f'kikyopp.{self.worker_name}',
+                    auto_ack=False,
+                )
 
         while self.is_running:
             try:
                 if not self.is_running:
                     break
-                msg = self.consumer.receive()
+                with self._lock:
+                    msg = self.consumer.receive()
 
                 if self._delay is not None:
                     t = msg.publish_time.timestamp() + self._delay - time.time()
